{% import 'macros/form.html' as form %}

{{ form.input('video_url', id='field-video_url', label=_('Video url'), placeholder=_('eg. http://example.com  (if blank uses resource url)'), value=data.video_url, error=errors.video_url, classes=['control-full', 'control-large']) }}

{{ form.input('width', id='field-width', label=_('Width'), value=(data.width or defaults['width']), error=errors.width) }}
{{ form.input('height', id='field-height', label=_('height'), value=(data.height or defaults['height']), error=errors.height) }}
