#!/usr/bin/env python
# encoding: utf-8
#
# This file is part of ckanext-video
# Created by the Natural History Museum in London, UK

import setuptools

if __name__ == '__main__':
    setuptools.setup()
